@@ -28,15 +28,14 @@ public:
 protected Q_SLOTS:
     void usrWriteConfig() override;
     void usrReadConfig() override;
+
+private:
     void configureClicked(QAction *action);
     void selectionChanged();
     void positioningChanged();
-
-private:
-    QTreeWidget *mTreeWidget = nullptr;
-    QLabel *mDescription = nullptr;
-    QPushButton *mConfigureButton = nullptr;
-    QGroupBox *mPositioningGroupBox = nullptr;
+    QTreeWidget *const mTreeWidget;
+    QLabel *const mDescription;
+    QGroupBox *const mPositioningGroupBox;
 
     QRadioButton *mPositionAgendaTop = nullptr;
     QRadioButton *mPositionAgendaBottom = nullptr;
@@ -45,4 +44,3 @@ private:
     QSet<QString> mDecorationsAtAgendaViewTop;
     QSet<QString> mDecorationsAtAgendaViewBottom;
 };
-
